@@ -20,11 +20,11 @@ HTML::FromArrayref - Output HTML described by a Perl data structure
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =cut
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ is an optional hashref defining the element's attributes. If an attribute's valu
 
 =head3 @content
 
-is another list of strings and arrayrefs, which will be used to generate the content of the element. If the content list is empty, then the element has no content and will be represented in the generated HTML string by a single tag that ends with " B</E<gt>>".
+is another list of strings and arrayrefs, which will be used to generate the content of the element. If the content list is empty, then the element has no content and will be represented in the generated HTML string by adjacent start and end tags. The content of elements that are defined in the HTML 4.01 specification as "void" will be discarded, and only their start tag will be printed.
 
 =cut
 
@@ -232,7 +232,9 @@ would print
   <td colspan="3">
   </td>
 
-=cut
+=head1 SEE ALSO
+
+L<The HTML 4.01 specification|http://www.w3.org/TR/html401/>
 
 =head1 AUTHOR
 
@@ -240,12 +242,7 @@ Nic Wolff, <nic@angel.net>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-html-fromarrayref at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-FromArrayref>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+Please report any bugs or feature requests through the web interface at L<https://github.com/nicwolff/HTML-FromArrayref/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -253,33 +250,28 @@ You can find documentation for this module with the perldoc command.
 
     perldoc HTML::FromArrayref
 
-
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * This module on GitHub
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-FromArrayref>
+L<https://github.com/nicwolff/HTML-FromArrayref>
+
+=item * GitHub request tracker (report bugs here)
+
+L<https://github.com/nicwolff/HTML-FromArrayref/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/HTML-FromArrayref>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/HTML-FromArrayref>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/HTML-FromArrayref/>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2012 Nic Wolff.
@@ -290,7 +282,6 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-
 =cut
 
 1; # End of HTML::FromArrayref
